@@ -13,29 +13,14 @@
 #include <KLocalizedString>
 #include <QApplication>
 #include <QCommandLineParser>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <Kdelibs4ConfigMigrator>
-#endif
 
 #include "gui/mainwindow.h"
 
 int main(int argc, char *argv[])
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    Kdelibs4ConfigMigrator migrate(QStringLiteral("picmi"));
-    migrate.setConfigFiles(QStringList() << QStringLiteral("picmirc"));
-    migrate.setUiFiles(QStringList() << QStringLiteral("picmiui.rc"));
-    migrate.migrate();
-#endif
-
-    // Fixes blurry icons with fractional scaling
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("picmi");
 
-
     KAboutData about(QStringLiteral("picmi"),
                       i18n("Picmi"),
                       QStringLiteral(PICMI_VERSION_STRING),
@@ -46,10 +31,12 @@ int main(int argc, char *argv[])
                       QStringLiteral("https://apps.kde.org/picmi"));
     about.addAuthor(i18n("Jakob Gruber"), i18n("Picmi Author"), QStringLiteral("jakob.gruber@gmail.com"));
 
+    KAboutData::setApplicationData(about);
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("picmi")));
+
+    KCrash::initialize();
 
     QCommandLineParser parser;
-    KAboutData::setApplicationData(about);
-    KCrash::initialize();
     about.setupCommandLine(&parser);
     parser.process(app);
     about.processCommandLine(&parser);
@@ -59,7 +46,5 @@ int main(int argc, char *argv[])
     MainWindow *w = new MainWindow;
     w->show();
 
-    app.setWindowIcon(QIcon::fromTheme(QStringLiteral("picmi")));
-
     return app.exec();
 }
